@@ -37,12 +37,13 @@
 #' FALSE.
 #' @param separate_results if TRUE (default is FALSE), then the separate parts
 #' of the interval score (sharpness, penalties for over- and under-prediction
-#' get returned as separate elements of a list)
+#' get returned as separate elements of a list). If you want a `data.frame`
+#' instead, simply call `as.data.frmae()` on the output.
 #' @return vector with the scoring values, or a list with separate entries if
 #' \code{separate_results} is TRUE.
 #' @examples
 #' true_values <- rnorm(30, mean = 1:30)
-#' interval_range = 90
+#' interval_range = rep(90, 30)
 #' alpha = (100 - interval_range) / 100
 #' lower = qnorm(alpha/2, rnorm(30, mean = 1:30))
 #' upper = qnorm((1- alpha/2), rnorm(30, mean = 1:30))
@@ -51,6 +52,12 @@
 #'                lower = lower,
 #'                upper = upper,
 #'                interval_range = interval_range)
+#'
+#' interval_score(true_values = c(true_values, NA),
+#'                lower = c(lower, NA),
+#'                upper = c(NA, upper),
+#'                separate_results = TRUE,
+#'                interval_range = 90)
 #' @export
 #' @references Strictly Proper Scoring Rules, Prediction,and Estimation,
 #' Tilmann Gneiting and Adrian E. Raftery, 2007, Journal of the American
@@ -68,22 +75,28 @@
 interval_score <- function(true_values,
                            lower,
                            upper,
-                           interval_range = NULL,
+                           interval_range,
                            weigh = TRUE,
                            separate_results = FALSE) {
 
-  if(is.null(interval_range)) {
-    stop("must provide a range for your prediction interval")
+  # error handling - not sure how I can make this better
+  present <- c(methods::hasArg("true_values"), methods::hasArg("lower"),
+               methods::hasArg("upper"), methods::hasArg("interval_range"))
+  if (!all(present)) {
+    stop("need all arguments 'true_values', 'lower', 'upper' and 'interval_range' in function 'interval_score()'")
   }
+  check_not_null(true_values = true_values, lower = lower, upper = upper,
+                 interval_range = interval_range)
+  check_equal_length(true_values, lower, interval_range, upper)
 
+  # calculate alpha from the interval range
   alpha <- (100 - interval_range) / 100
 
+  # calculate three components of WIS
   sharpness <- (upper - lower)
   overprediction <- 2/alpha * (lower - true_values) * (true_values < lower)
   underprediction <- 2/alpha * (true_values - upper) * (true_values > upper)
 
-
-
   if (weigh) {
     sharpness <- sharpness * alpha / 2
     underprediction <- underprediction * alpha / 2
@@ -101,3 +114,5 @@ interval_score <- function(true_values,
     return(score)
   }
 }
+
+
